# kenghwee
A package where a meme becomes reality.

## Description

As of now, the `kenghwee` package supports two things:

- `solution`: living up the meme `from kenghwee import solution`
- `mission04`: additional function that is under development

## Installation

### Normal installation

```bash
pip install kenghwee
```

### Development installation

```bash
git clone https://github.com/RussellDash332/kenghwee.git
cd kenghwee
pip install --editable .
```

## Contributing
Make a pull request, that's it :)